revno — Breezy 3.0.2dev documentation

Table of Contents (3.0.2dev)

# revno

Purpose

  Show current revision number.

Usage

  brz revno [LOCATION]

Options
  `-h, --help`

    Show help message.

  `-q, --quiet`

    Only display errors and warnings.

  `-r ARG, --revision=ARG`

    See “help revisionspec” for details.

  `--tree`

    Show revno of working tree.

  `--usage`

    Show usage message and options.

  `-v, --verbose`

    Display more information.

Description

  This is equal to the number of revisions on this branch.

See also

  info